
require('dotenv').config();
const { openAsBlob } = require('node:fs');
const { rm, stat } = require('fs/promises');
const path = require('path');

if (!process.env.IPFS_URL) throw new Error('IPFS_URL was missing in env');


async function streamingPostFetch(
    url,
    formData,
    basename,
    filesize
) {
    // console.log(`streamingPostFetch with url=${url}, formData=${formData.get('file')}, basename=${basename}, filesize=${filesize}`);

    try {
        const res = await fetch(url, {
            method: 'POST',
            body: formData
        });

        if (!res.ok) {
            throw new Error(`HTTP error! Status-- ${res.status}`);
        }

        const reader = res.body?.getReader();
        if (!reader) {
            throw new Error('Failed to get reader from response body');
        }


        while (true) {
            const { done, value } = await reader.read();

            const chunk = new TextDecoder().decode(value);
            const lines = chunk.split('\n');
            for (const line of lines) {
                const trimmedLine = line.trim()
                if (!!trimmedLine) {
                    // console.log(trimmedLine);
                    const json = JSON.parse(trimmedLine);
                    // console.log(`comparing json.Name=${json.Name} with basename=${basename}`);
                    if (json.Name === basename && json.Hash && json.Size) {
                        // this is the last chunk
                        return json;
                    }
                }
            }

            if (done) {
                throw new Error('Response reader finished before receiving a CID which indicates a failiure.');
            }

        }
    } catch (error) {
        console.error('An error occurred:', error);
        throw error;
    }
}


async function getFormStuff(filePath) {
    const url = `${process.env.IPFS_URL}/api/v0/add?progress=false&cid-version=1&pin=true`;
    const blob = await openAsBlob(filePath);
    const basename = path.basename(filePath);
    const filesize = (await stat(filePath)).size;
    const formData = new FormData();
    return {
        url,
        blob,
        basename,
        filesize,
        formData
    }
}


/**
 * @param {String} filePath 
 * @returns {String} CID
 */
const ipfsAdd = async function (filePath) {
    
    
    const { url: kuboUrl, blob, basename, filesize, formData } = await getFormStuff(filePath);
    

    formData.append('file', blob, basename);
    const output = await streamingPostFetch(kuboUrl, formData, basename, filesize);
    if (!output?.Hash) throw new Error('No CID was received from remote IPFS node.');
    const cid = output.Hash;


    return cid
}

module.exports = ipfsAdd;

